@@ -32,7 +32,7 @@ class Storage(driver.Base):
         
     def _init_path(self, path=None):
         if path:
-            if path.startwith('/'):
+            if path.startswith('/'):
                 path = path[1]
             if path.endswith('/'):
                 path = path[:-1]
